@@ -34,6 +34,7 @@ import org.jboss.dmr.ModelNode;
 import org.jboss.jca.common.api.metadata.common.XaPool;
 import org.jboss.jca.common.api.metadata.ds.DsXaPool;
 import org.jboss.jca.common.api.metadata.ds.XaDataSource;
+import org.jboss.modules.ModuleClassLoader;
 
 /**
  * Runtime attribute handler for XA XML datasources
@@ -322,6 +323,14 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
                 return;
             }
             setStringIfNotNull(context, dataSource.getValidation().getExceptionSorter().getClassName());
+        } else if (attributeName.equals(Constants.EXCEPTION_SORTER_MODULE.getName())) {
+            if (dataSource.getValidation() == null) {
+                return;
+            }
+            if (dataSource.getValidation().getExceptionSorter() == null) {
+                return;
+            }
+            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getExceptionSorter().getClassLoader()).getModule().toString());
         } else if (attributeName.equals(Constants.EXCEPTION_SORTER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -344,6 +353,14 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
                 return;
             }
             setStringIfNotNull(context, dataSource.getValidation().getStaleConnectionChecker().getClassName());
+        } else if (attributeName.equals(Constants.STALE_CONNECTION_CHECKER_MODULE.getName())) {
+            if (dataSource.getValidation() == null) {
+                return;
+            }
+            if (dataSource.getValidation().getStaleConnectionChecker() == null) {
+                return;
+            }
+            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getStaleConnectionChecker().getClassLoader()).getModule().toString());
         } else if (attributeName.equals(Constants.STALE_CONNECTION_CHECKER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -366,6 +383,14 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
                 return;
             }
             setStringIfNotNull(context, dataSource.getValidation().getValidConnectionChecker().getClassName());
+        } else if (attributeName.equals(Constants.VALID_CONNECTION_CHECKER_MODULE.getName())) {
+            if (dataSource.getValidation() == null) {
+                return;
+            }
+            if (dataSource.getValidation().getValidConnectionChecker() == null) {
+                return;
+            }
+            setStringIfNotNull(context, ((ModuleClassLoader)dataSource.getValidation().getValidConnectionChecker().getClassLoader()).getModule().toString());
         } else if (attributeName.equals(Constants.VALID_CONNECTION_CHECKER_PROPERTIES.getName())) {
             if (dataSource.getValidation() == null) {
                 return;
@@ -461,11 +486,6 @@ public class XMLXaDataSourceRuntimeHandler extends AbstractXMLDataSourceRuntimeH
             for (final Map.Entry<String, String> entry : propertiesMap.entrySet()) {
                 context.getResult().asPropertyList().add(new ModelNode().set(entry.getKey(), entry.getValue()).asProperty());
             }
-        } else if (attributeName.equals(Constants.ALLOCATION_RETRY.getName())) {
-            if (dataSource.getTimeOut() == null) {
-                return;
-            }
-            setIntIfNotNull(context, dataSource.getTimeOut().getAllocationRetry());
         } else if (attributeName.equals(Constants.QUERY_TIMEOUT.getName())) {
             if (dataSource.getTimeOut() == null) {
                 return;
